@@ -14,6 +14,7 @@ from mkdocs_autorefs._internal.references import (
     AutorefsExtension,
     AutorefsHookInterface,
     AutorefsInlineProcessor,
+    HeadingScannerTreeProcessor,
     fix_ref,
     fix_refs,
     relative_url,
@@ -31,6 +32,7 @@ __all__: list[str] = [
     "Backlink",
     "BacklinkCrumb",
     "BacklinksTreeProcessor",
+    "HeadingScannerTreeProcessor",
     "fix_ref",
     "fix_refs",
     "relative_url",
